==> lima-swing-0.7-sources.jar: org/chorem/lima/ui/celleditor/EntryBookTableCellRender.java <==
package org.chorem.lima.ui.celleditor;

/*
 * #%L
 * Lima :: Swing
 * $Id: EntryBookTableCellRender.java 3695 2013-07-10 09:11:39Z athimel $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.7/lima-swing/src/main/java/org/chorem/lima/ui/celleditor/EntryBookTableCellRender.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.chorem.lima.entity.EntryBook;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public class EntryBookTableCellRender extends EntryTableCellRenderer {

    @Override
    public void setValue(Object value) {
        Object result = value;
        if (value != null && value instanceof EntryBook) {
            EntryBook entryBook= (EntryBook) value;
            result = entryBook.getCode() + " - " + entryBook.getLabel();
        }
        super.setValue(result);
    }

}

==> lima-swing-0.7.1-sources.jar: org/chorem/lima/ui/celleditor/EntryBookTableCellRender.java <==
package org.chorem.lima.ui.celleditor;

/*
 * #%L
 * Lima :: Swing
 * $Id: EntryBookTableCellRender.java 3721 2013-12-31 15:03:48Z sbavencoff $
 * $HeadURL: https://svn.chorem.org/lima/tags/lima-0.7.1/lima-swing/src/main/java/org/chorem/lima/ui/celleditor/EntryBookTableCellRender.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.chorem.lima.entity.EntryBook;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public class EntryBookTableCellRender extends DefaultLimaTableCellRenderer {

    @Override
    public void setValue(Object value) {
        Object result = value;
        if (value != null && value instanceof EntryBook) {
            EntryBook entryBook= (EntryBook) value;
            result = entryBook.getCode() + " - " + entryBook.getLabel();
        }
        super.setValue(result);
    }

}
